from distutils.core import setup

packages = \
['cleo',
 'cleo.commands',
 'cleo.commands.completions',
 'cleo.descriptors',
 'cleo.exceptions',
 'cleo.formatters',
 'cleo.helpers',
 'cleo.inputs',
 'cleo.outputs',
 'cleo.questions',
 'cleo.styles',
 'cleo.testers',
 'cleo.validators']

package_data = \
{'': ['*']}

install_requires = \
['pylev (>=1.3.0.0,<2.0.0.0)', 'pastel (>=0.1.0.0,<0.2.0.0)']

setup_kwargs = {
    'name': 'cleo',
    'version': '0.6.2',
    'description': 'Cleo allows you to create beautiful and testable command-line interfaces.',
    'long_description': 'Cleo\n####\n\n.. image:: https://travis-ci.org/sdispater/cleo.png\n   :alt: Cleo Build status\n   :target: https://travis-ci.org/sdispater/cleo\n\nCreate beautiful and testable command-line interfaces.\n\nResources\n=========\n\n* `Documentation <http://cleo.readthedocs.io>`_\n* `Issue Tracker <https://github.com/sdispater/cleo/issues>`_\n\n\nUsage\n=====\n\nTo make a command that greets you from the command line,\ncreate ``greet_command.py`` and add the following to it:\n\n.. code-block:: python\n\n    from cleo import Command\n\n\n    class GreetCommand(Command):\n        """\n        Greets someone\n\n        demo:greet\n            {name? : Who do you want to greet?}\n            {--y|yell : If set, the task will yell in uppercase letters}\n        """\n\n        def handle(self):\n            name = self.argument(\'name\')\n\n            if name:\n                text = \'Hello %s\' % name\n            else:\n                text = \'Hello\'\n\n            if self.option(\'yell\'):\n                text = text.upper()\n\n            self.line(text)\n\n\nYou also need to create the file to run at the command line which creates\nan ``Application`` and adds commands to it:\n\n.. code-block:: python\n\n    #!/usr/bin/env python\n    # -*- coding: utf-8 -*-\n\n    from greet_command import GreetCommand\n    from cleo import Application\n\n    application = Application()\n    application.add(GreetCommand())\n\n    if __name__ == \'__main__\':\n        application.run()\n\nTest the new command by running the following\n\n.. code-block:: bash\n\n    $ python application.py demo:greet John\n\nThis will print the following to the command line:\n\n.. code-block:: text\n\n    Hello John\n\nYou can also use the ``--yell`` option to make everything uppercase:\n\n.. code-block:: bash\n\n    $ python application.py demo:greet John --yell\n\nThis prints:\n\n.. code-block:: text\n\n    HELLO JOHN\n\nAs you may have already seen, Cleo uses the command docstring to determine\nthe command definition.\nThe docstring must be in the following form :\n\n.. code-block:: python\n\n    """\n    Command description\n\n    Command signature\n    """\n\nThe signature being in the following form:\n\n.. code-block:: python\n\n    """\n    command:name {argument : Argument description} {--option : Option description}\n    """\n\nThe signature can span multiple lines.\n\n.. code-block:: python\n\n    """\n    command:name\n        {argument : Argument description}\n        {--option : Option description}\n    """\n\nColoring the Output\n-------------------\n\nWhenever you output text, you can surround the text with tags to color its\noutput. For example:\n\n.. code-block:: python\n\n    # green text\n    self.line(\'<info>foo</info>\')\n\n    # yellow text\n    self.line(\'<comment>foo</comment>\')\n\n    # black text on a cyan background\n    self.line(\'<question>foo</question>\')\n\n    # white text on a red background\n    self.line(\'<error>foo</error>\')\n\nThe closing tag can be replaced by ``</>``, which revokes all formatting options established by the last opened tag.\n\nYou can also use the corresponding methods:\n\n.. code-block:: python\n\n    self.info(\'foo\')\n    self.comment(\'foo\')\n    self.question(\'foo\')\n    self.error(\'foo\')\n\nIt is possible to define your own styles using the ``set_style()`` method:\n\n.. code-block:: python\n\n    self.set_style(\'fire\', fg=\'red\', bg=\'yellow\', options=[\'bold\', \'blink\'])\n    self.line(\'<fire>foo</fire>\')\n\nAvailable foreground and background colors are: ``black``, ``red``, ``green``,\n``yellow``, ``blue``, ``magenta``, ``cyan`` and ``white``.\n\nAnd available options are: ``bold``, ``underscore``, ``blink``, ``reverse`` and ``conceal``.\n\nYou can also set these colors and options inside the tagname:\n\n.. code-block:: python\n\n    # green text\n    self.line(\'<fg=green>foo</>\')\n\n    # black text on a cyan background\n    self.line(\'<fg=black;bg=cyan>foo</>\')\n\n    # bold text on a yellow background\n    self.line(\'<bg=yellow;options=bold>foo</>\')\n\n\nVerbosity Levels\n----------------\n\nCleo has five verbosity levels. These are defined in the ``Output`` class:\n\n=======================================  ================================== ======================\nMode                                     Meaning                            Console option\n=======================================  ================================== ======================\n``Output.VERBOSITY_QUIET``               Do not output any messages         ``-q`` or ``--quiet``\n``Output.VERBOSITY_NORMAL``              The default verbosity level        (none)\n``Output.VERBOSITY_VERBOSE``             Increased verbosity of messages    ``-v``\n``Output.VERBOSITY_VERY_VERBOSE``        Informative non essential messages ``-vv``\n``Output.VERBOSITY_DEBUG``               Debug messages                     ``-vvv``\n=======================================  ================================== ======================\n\nIt is possible to print a message in a command for only a specific verbosity\nlevel. For example:\n\n.. code-block:: python\n\n    if Output.VERBOSITY_VERBOSE <= self.output.get_verbosity():\n        self.line(...)\n\nThere are also more semantic methods you can use to test for each of the\nverbosity levels:\n\n.. code-block:: python\n\n    if self.output.is_quiet():\n        # ...\n\n    if self.output.is_verbose():\n        # ...\n\nWhen the quiet level is used, all output is suppressed as the default\n``Output.write()`` method returns without actually printing.\n\n\nUsing Arguments\n---------------\n\nThe most interesting part of the commands are the arguments and options that\nyou can make available. Arguments are the strings - separated by spaces - that\ncome after the command name itself. They are ordered, and can be optional\nor required. For example, add an optional ``last_name`` argument to the command\nand make the ``name`` argument required:\n\n.. code-block:: python\n\n    class GreetCommand(Command):\n        """\n        Greets someone\n\n        demo:greet\n            {name : Who do you want to greet?}\n            {last_name? : Your last name?}\n            {--y|yell : If set, the task will yell in uppercase letters}\n        """\n\nYou now have access to a ``last_name`` argument in your command:\n\n.. code-block:: python\n\n    last_name = self.argument(\'last_name\')\n    if last_name:\n        text += \' %s\' % last_name\n\nThe command can now be used in either of the following ways:\n\n.. code-block:: bash\n\n    $ python application.py demo:greet John\n    $ python application.py demo:greet John Doe\n\nIt is also possible to let an argument take a list of values (imagine you want\nto greet all your friends). For this it must be specified at the end of the\nargument list:\n\n.. code-block:: python\n\n    class GreetCommand(Command):\n        """\n        Greets someone\n\n        demo:greet\n            {names* : Who do you want to greet?}\n            {--y|yell : If set, the task will yell in uppercase letters}\n        """\n\nTo use this, just specify as many names as you want:\n\n.. code-block:: bash\n\n    $ python application.py demo:greet John Jane\n\nYou can access the ``names`` argument as a list:\n\n.. code-block:: python\n\n    names = self.argument(\'names\')\n    if names:\n        text += \' %s\' % \', \'.join(names)\n\nThere are 3 argument variants you can use:\n\n=========================== ==================================== ===============================================================================================================\nMode                        Notation                             Value\n=========================== ==================================== ===============================================================================================================\n``InputArgument.REQUIRED``  none (just write the argument name)  The argument is required\n``InputArgument.OPTIONAL``  ``argument?``                        The argument is optional and therefore can be omitted\n``InputArgument.IS_LIST``   ``argument*``                        The argument can contain an indefinite number of arguments and must be used at the end of the argument list\n=========================== ==================================== ===============================================================================================================\n\nYou can combine ``IS_LIST`` with ``REQUIRED`` and ``OPTIONAL`` like this:\n\n.. code-block:: python\n\n    class GreetCommand(Command):\n        """\n        Greets someone\n\n        demo:greet\n            {names?* : Who do you want to greet?}\n            {--y|yell : If set, the task will yell in uppercase letters}\n        """\n\nIf you want to set a default value, you can it like so:\n\n.. code-block:: text\n\n    argument=default\n\nThe argument will then be considered optional.\n\n\nUsing Options\n-------------\n\nUnlike arguments, options are not ordered (meaning you can specify them in any\norder) and are specified with two dashes (e.g. ``--yell`` - you can also\ndeclare a one-letter shortcut that you can call with a single dash like\n``-y``). Options are *always* optional, and can be setup to accept a value\n(e.g. ``--dir=src``) or simply as a boolean flag without a value (e.g.\n``--yell``).\n\n.. tip::\n\n    It is also possible to make an option *optionally* accept a value (so that\n    ``--yell`` or ``--yell=loud`` work). Options can also be configured to\n    accept a list of values.\n\nFor example, add a new option to the command that can be used to specify\nhow many times in a row the message should be printed:\n\n.. code-block:: python\n\n    class GreetCommand(Command):\n        """\n        Greets someone\n\n        demo:greet\n            {name? : Who do you want to greet?}\n            {--y|yell : If set, the task will yell in uppercase letters}\n            {--iterations=1 : How many times should the message be printed?}\n        """\n\n\nNext, use this in the command to print the message multiple times:\n\n.. code-block:: python\n\n    for _ in range(0, self.option(\'iterations\')):\n        self.line(text)\n\nNow, when you run the task, you can optionally specify a ``--iterations``\nflag:\n\n.. code-block:: bash\n\n    $ python application.py demo:greet John\n    $ python application.py demo:greet John --iterations=5\n\nThe first example will only print once, since ``iterations`` is empty and\ndefaults to ``1``. The second example will print five times.\n\nRecall that options don\'t care about their order. So, either of the following\nwill work:\n\n.. code-block:: bash\n\n    $ python application.py demo:greet John --iterations=5 --yell\n    $ python application.py demo:greet John --yell --iterations=5\n\nThere are 4 option variants you can use:\n\n===============================  =================================== ======================================================================================\nOption                           Notation                            Value\n===============================  =================================== ======================================================================================\n``InputOption.VALUE_IS_LIST``    ``--option=*``                      This option accepts multiple values (e.g. ``--dir=/foo --dir=/bar``)\n``InputOption.VALUE_NONE``       ``--option``                        Do not accept input for this option (e.g. ``--yell``)\n``InputOption.VALUE_REQUIRED``   ``--option=``                       This value is required (e.g. ``--iterations=5``), the option itself is still optional\n``InputOption.VALUE_OPTIONAL``   ``--option=?``                      This option may or may not have a value (e.g. ``--yell`` or ``--yell=loud``)\n===============================  =================================== ======================================================================================\n\nYou can combine ``VALUE_IS_LIST`` with ``VALUE_REQUIRED`` or ``VALUE_OPTIONAL`` like this:\n\n.. code-block:: python\n\n    class GreetCommand(Command):\n        """\n        Greets someone\n\n        demo:greet\n            {name? : Who do you want to greet?}\n            {--y|yell : If set, the task will yell in uppercase letters}\n            {--iterations=?*1 : How many times should the message be printed?}\n        """\n\n\nTesting Commands\n----------------\n\nCleo provides several tools to help you test your commands. The most\nuseful one is the ``CommandTester`` class.\nIt uses special input and output classes to ease testing without a real\nconsole:\n\n.. code-block:: python\n\n    from unittest import TestCase\n    from cleo import Application, CommandTester\n\n    class GreetCommandTest(TestCase):\n\n        def test_execute(self):\n            application = Application()\n            application.add(GreetCommand())\n\n            command = application.find(\'demo:greet\')\n            command_tester = CommandTester(command)\n            command_tester.execute([(\'command\', command.get_name())])\n\n            self.assertRegex(\'...\', command_tester.get_display())\n\n            # ...\n\nThe ``CommandTester.get_display()`` method returns what would have been displayed\nduring a normal call from the console.\n\nYou can test sending arguments and options to the command by passing them\nas an list of tuples to the ``CommandTester.execute()`` method:\n\n.. code-block:: python\n\n    from unittest import TestCase\n    from cleo import Application, CommandTester\n\n    class GreetCommandTest(TestCase):\n\n        def test_name_is_output(self):\n            application = Application()\n            application.add(GreetCommand())\n\n            commmand = application.find(\'demo:greet\')\n            command_tester = CommandTester(command)\n            command_tester.execute([\n                (\'command\', command.get_name()),\n                (\'name\', \'John\')\n            ])\n\n            self.assertRegex(\'John\', command_tester.get_display())\n\nYou can also test a whole console application by using the ``ApplicationTester`` class.\n\n\nCalling an existing Command\n---------------------------\n\nIf a command depends on another one being run before it, instead of asking the\nuser to remember the order of execution, you can call it directly yourself.\nThis is also useful if you want to create a "meta" command that just runs a\nbunch of other commands.\n\nCalling a command from another one is straightforward:\n\n.. code-block:: python\n\n    def handle(self):\n        return_code = self.call(\'demo:greet\', [\n            (\'name\', \'John\'),\n            (\'--yell\', True)\n        ])\n\n        # ...\n\nIf you want to suppress the output of the executed command,\nyou can use the ``call_silent()`` method instead.\n\n\n\nAutocompletion\n--------------\n\nCleo supports automatic (tab) completion in ``bash`` and ``zsh``.\n\nTo activate support for autocompletion, pass a ``complete`` keyword when initializing\nyour application:\n\n.. code-block:: python\n\n    application = Application(\'My Application\', \'0.1\', complete=True)\n\nNow, register completion for your application by running one of the following in a terminal,\nreplacing ``[program]`` with the command you use to run your application:\n\n.. code-block:: bash\n\n    # BASH ~4.x, ZSH\n    source <([program] _completion --generate-hook)\n\n    # BASH ~3.x, ZSH\n    [program] _completion --generate-hook | source /dev/stdin\n\n    # BASH (any version)\n    eval $([program] _completion --generate-hook)\n\nBy default this registers completion for the absolute path to you application,\nwhich will work if the program is accessible on your PATH.\nYou can specify a program name to complete for instead using the ``-p\\--program`` option,\nwhich is required if you\'re using an alias to run the program.\n\nIf you want the completion to apply automatically for all new shell sessions,\nadd the command to your shell\'s profile (eg. ``~/.bash_profile`` or ``~/.zshrc``)\n\nThe type of shell (zsh/bash) is automatically detected using the ``SHELL`` environment variable at run time.\nIn some circumstances, you may need to explicitly specify the shell type with the ``--shell-type`` option.\n',
    'author': 'Sébastien Eustace',
    'author_email': 'sebastien@eustace.io',
    'url': 'https://github.com/sdispater/cleo',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*',
}


setup(**setup_kwargs)
